@@ -12,7 +12,7 @@ class DiskCache(MemCache):
     def __init__(self, dcache=None, prefix="rc", serializer=dumps, deserializer=loads):
         dcache = dcache or DCache()
         # Use BaseCache init rather than the MemCache one..
-        super(MemCache, self).__init__(DiskCacheDecorator, dcache, prefix, serializer, deserializer)
+        super().__init__(DiskCacheDecorator, dcache, prefix, serializer, deserializer)
 
 
 class DiskCacheDecorator(MemCacheDecorator):
