@@ -65,7 +65,11 @@ class RedisCache(BaseCache):
         deserialized_results = []
         needs_pipeline = False
         for i, result in enumerate(results):
-            if result is None:
+            if result:
+                result = self.deserializer(result)
+            elif isinstance(fns_with_args[i], str):
+                pass  # results are none since we cannot retroactively run function..
+            else:
                 needs_pipeline = True
 
                 fn_and_args = fns_with_args[i]
@@ -75,8 +79,6 @@ class RedisCache(BaseCache):
                 result = fn.instance.original_fn(*args, **kwargs)
                 result_serialized = self.serializer(result)
                 get_cache_lua_fn(self._cache)(keys=[keys[i], fn.instance.keys_key], args=[result_serialized, fn.instance.ttl, fn.instance.limit], client=pipeline)
-            else:
-                result = self.deserializer(result)
             deserialized_results.append(result)
 
         if needs_pipeline:
